Attribute VB_Name = "MailPdfPlus"
Sub MailPdfPlusOriginal()

'=================================================================
'Description: Excel macro to create a pdf-file of the current
'             workbook and add both the original and the
'             pdf-version of the workbook as an attachment to
'             a new Outlook message.
'
'Important!   This macro requires a reference added to the
'             Microsoft Outlook <version> Object Library
'             In VBA Editor: Tools-> References...
'
'author : Robert Sparnaaij
'version: 1.0
'website: https://www.howto-outlook.com/howto/mailpdfplus.htm
'=================================================================

    'Verify if the workbook has been saved before so that we have a path to work with.
    'If not, notify the user that there will be a safe dialog first.
    If ActiveWorkbook.Path <> "" Then
        ActiveWorkbook.Save
    Else
        Dim Msg, Style, Title, Response
        Msg = "This workbook has not been saved before." & vbLf & _
        "Please save the workbook to disk first." & vbLf & _
        "Without saving first, only the pdf-file will be attached."
        Style = vbInformation + vbOKOnly
        Title = "Save current presentation"
        Response = MsgBox(Msg, Style, Title)
        
        Dim dlgSaveAs As FileDialog
        Dim strCurrentFile As String
        Set dlgSaveAs = Application.FileDialog(msoFileDialogSaveAs)
        
        If dlgSaveAs.Show = -1 Then
            strCurrentFile = dlgSaveAs.SelectedItems(1)
            ActiveWorkbook.SaveAs (strCurrentFile)
        End If
        Set dlgSaveAs = Nothing
    End If

    'Get the name of the open file and strip any extension.
    Dim MyFile As String
    MyFile = ActiveWorkbook.Name
    intPos = InStrRev(MyFile, ".")
    If intPos > 0 Then
        MyFile = Left(MyFile, intPos - 1)
    End If

    'Get the user's TempFolder to store the created pdf item in.
    Dim FSO As Object, TmpFolder As Object
    Set FSO = CreateObject("scripting.filesystemobject")
    Set Filename = FSO.GetSpecialFolder(2)
    
    'Create the full path name for the pdf-file
    Filename = Filename & "\" & MyFile & ".pdf"
 
    'Save the current workbook as pdf in the user's temp folder.
    'Note that we are going to include the workbook properties as well.
    'If you do not want this set "IncludeDocProperties" to False.
    ActiveWorkbook.ExportAsFixedFormat Type:=xlTypePDF, Filename:= _
        Filename, Quality:=xlQualityStandard, _
        IncludeDocProperties:=True, IgnorePrintAreas:=False, OpenAfterPublish:= _
        False

    'Declare an Outlook application an a mail item.
    Dim oOutlookApp As Outlook.Application
    Dim oItem As Outlook.MailItem

    'Start Outlook if it isn't running.
    Set oOutlookApp = GetObject(, "Outlook.Application")
    If Err <> 0 Then
        Set oOutlookApp = CreateObject("Outlook.Application")
    End If

    'Create a new message.
    Set oItem = oOutlookApp.CreateItem(olMailItem)

    'Add the attachments.
    oItem.Attachments.Add Filename
    oItem.Attachments.Add ActiveWorkbook.FullName

    'Show the message.
    oItem.Display
    
    'Cleanup
    Set FSO = Nothing
    Set FileName = Nothing
    Set oOutlookApp = Nothing
    Set oItem = Nothing

End Sub
